@@ -24,9 +24,13 @@ the following defined clusters on this endpoint:
 The required clusters for this endpoint: Scenes, OnOff and Groups.
 The optional clusters for this endpoint: Level and Occupancy.
 """
+from typing import Union
+
 from gazoo_device import decorators
+from gazoo_device.capabilities import matter_enums
 from gazoo_device.capabilities.matter_clusters import level_control_pw_rpc
 from gazoo_device.capabilities.matter_clusters import occupancy_pw_rpc
+from gazoo_device.capabilities.matter_clusters import on_off_chip_tool
 from gazoo_device.capabilities.matter_clusters import on_off_pw_rpc
 from gazoo_device.capabilities.matter_endpoints.interfaces import on_off_light_base
 
@@ -37,17 +41,21 @@ class OnOffLightEndpoint(on_off_light_base.OnOffLightBase):
   @decorators.CapabilityDecorator(level_control_pw_rpc.LevelControlClusterPwRpc)
   def level(self) -> level_control_pw_rpc.LevelControlClusterPwRpc:
     """Matter Level Control cluster instance."""
-    return self.cluster_lazy_init(level_control_pw_rpc.LevelControlClusterPwRpc)
+    return self.cluster_lazy_init(matter_enums.LevelControlCluster.ID)
 
   @decorators.CapabilityDecorator(occupancy_pw_rpc.OccupancyClusterPwRpc)
   def occupancy(self) -> occupancy_pw_rpc.OccupancyClusterPwRpc:
     """Matter Occupancy cluster instance."""
-    return self.cluster_lazy_init(occupancy_pw_rpc.OccupancyClusterPwRpc)
+    return self.cluster_lazy_init(matter_enums.OccupancySensingCluster.ID)
 
-  @decorators.CapabilityDecorator(on_off_pw_rpc.OnOffClusterPwRpc)
-  def on_off(self) -> on_off_pw_rpc.OnOffClusterPwRpc:
+  @decorators.CapabilityDecorator(
+      [on_off_chip_tool.OnOffClusterChipTool, on_off_pw_rpc.OnOffClusterPwRpc])
+  def on_off(
+      self
+  ) -> Union[on_off_chip_tool.OnOffClusterChipTool,
+             on_off_pw_rpc.OnOffClusterPwRpc]:
     """Matter OnOff cluster instance."""
-    return self.cluster_lazy_init(on_off_pw_rpc.OnOffClusterPwRpc)
+    return self.cluster_lazy_init(matter_enums.OnOffCluster.ID)
 
   # TODO(b/209362086) Add the below clusters
   # def scenes(self):
