@@ -47,16 +47,6 @@ class PwRPCCommonDefault(pwrpc_common_base.PwRPCCommonBase):
     self._switchboard_call = switchboard_call
     self._rpc_timeout_s = rpc_timeout_s
 
-  @decorators.DynamicProperty
-  def vendor_id(self) -> int:
-    """The vendor id of the device."""
-    return self.get_device_info().vendor_id
-
-  @decorators.DynamicProperty
-  def product_id(self) -> int:
-    """The product id of the device."""
-    return self.get_device_info().product_id
-
   @decorators.DynamicProperty
   def software_version(self) -> int:
     """The software version of the device."""
